@@ -28,7 +28,7 @@ struct _MailStubExchange {
 	E2kContext *ctx;
 	GHashTable *folders_by_name;
 	const char *mail_submission_uri;
-	EFolder *inbox, *deleted_items;
+	EFolder *inbox, *deleted_items, *sent_items;
 
 	guint new_folder_id, removed_folder_id;
 	const char *ignore_new_folder, *ignore_removed_folder;
